@@ -30,3 +30,6 @@ class BaseItem:
         kwargs.setdefault('ensure_ascii', False)
 
         return json.dumps(self.to_dict(), **kwargs)
+
+    def __str__(self):
+        return f"<{self.__class__.__name__} table:{self.__class__.table} item:{self.to_dict()}>"
